@@ -27,7 +27,7 @@ HostPreferencesList::HostPreferencesList(QWidget *parent, MainWindow *mainWindow
 
     configureButton = new QPushButton(this);
     configureButton->setEnabled(false);
-    configureButton->setText(i18n("Configure..."));
+    configureButton->setText(i18n("Configure…"));
     configureButton->setIcon(QIcon::fromTheme(QLatin1String("configure")));
     connect(configureButton, SIGNAL(clicked()), SLOT(configureHost()));
 
