@@ -6,8 +6,6 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#include "config-kactivities.h"
-
 #include "bookmarkmanager.h"
 #include "config/preferencesdialog.h"
 #include "connectiondelegate.h"
@@ -33,10 +31,6 @@
 #include <KToggleFullScreenAction>
 #include <KToolBar>
 
-#if HAVE_KACTIVITIES
-#include <PlasmaActivities/ResourceInstance>
-#endif
-
 #include <QClipboard>
 #include <QDockWidget>
 #include <QFontMetrics>
@@ -334,10 +328,6 @@ void MainWindow::newConnection(const QUrl &newUrl, bool switchFullscreenWhenConn
     view->start();
     setFactor(view->hostPreferences()->scaleFactor());
 
-#if HAVE_KACTIVITIES
-    KActivities::ResourceInstance::notifyAccessed(url, QGuiApplication::desktopFileName());
-#endif
-
     Q_EMIT factorUpdated(view->hostPreferences()->scaleFactor());
     Q_EMIT scaleUpdated(scale_state);
 }
