@@ -10,7 +10,6 @@
 #include "rdphostpreferences.h"
 
 #include <algorithm>
-#include <memory>
 
 #include <QApplication>
 #include <QKeyEvent>
@@ -21,10 +20,8 @@
 #include <freerdp/client.h>
 #include <freerdp/client/channels.h>
 #include <freerdp/client/cmdline.h>
-#include <freerdp/client/disp.h>
 #include <freerdp/client/rdpgfx.h>
 #include <freerdp/event.h>
-#include <freerdp/freerdp.h>
 #include <freerdp/gdi/gdi.h>
 #include <freerdp/gdi/gfx.h>
 #include <freerdp/input.h>
@@ -628,6 +625,9 @@ int RdpSession::clientContextStart(rdpContext *context)
     if (!freerdp_settings_set_bool(settings, FreeRDP_ConsoleSession, preferences->consoleMode())) {
         return -1;
     }
+    if (preferences->preventSessionLock() && !freerdp_settings_set_uint32(settings, FreeRDP_FakeMouseMotionInterval, 180)) {
+        return -1;
+    }
 
     if (!preferences->authPkgList().isEmpty()
         && !freerdp_settings_set_string(settings, FreeRDP_AuthenticationPackageList, preferences->authPkgList().toUtf8().data())) {
@@ -766,7 +766,7 @@ BOOL RdpSession::endPaint(rdpContext *context)
     WINPR_ASSERT(session);
 
     auto gdi = context->gdi;
-    if (!gdi || !gdi->primary) {
+    if (!gdi || !gdi->primary || !gdi->primary->hdc || !gdi->primary->hdc->hwnd || !gdi->primary->hdc->hwnd->invalid) {
         return false;
     }
 
@@ -987,9 +987,14 @@ bool RdpSession::sendEvent(QEvent *event, QWidget *source)
     switch (event->type()) {
     case QEvent::KeyPress:
     case QEvent::KeyRelease: {
+        if (m_needKeyStateSync) {
+            m_needKeyStateSync = false;
+            syncKeyState();
+        }
         auto keyEvent = static_cast<QKeyEvent *>(event);
+        auto keyboardType = freerdp_settings_get_uint32(m_context.rdp->settings, FreeRDP_KeyboardType);
         const DWORD vc = GetVirtualKeyCodeFromKeycode(keyEvent->nativeScanCode(), WINPR_KEYCODE_TYPE_XKB);
-        const DWORD code = GetVirtualScanCodeFromVirtualKeyCode(vc, WINPR_KBD_TYPE_IBM_ENHANCED);
+        const DWORD code = GetVirtualScanCodeFromVirtualKeyCode(vc, keyboardType);
         freerdp_input_send_keyboard_event_ex(input, keyEvent->type() == QEvent::KeyPress, keyEvent->isAutoRepeat(), code);
         return true;
     }
@@ -1090,6 +1095,26 @@ bool RdpSession::sendEvent(QEvent *event, QWidget *source)
     return QObject::event(event);
 }
 
+bool RdpSession::syncKeyState()
+{
+    auto input = m_context.rdp->input;
+    if (!input) {
+        return false;
+    }
+
+    UINT16 flags = 0;
+
+    if (m_view->isCapsLockEnabled())
+        flags |= KBD_SYNC_CAPS_LOCK;
+    if (m_view->isNumLockEnabled())
+        flags |= KBD_SYNC_NUM_LOCK;
+    if (m_view->isScrollLockEnabled())
+        flags |= KBD_SYNC_SCROLL_LOCK;
+
+    qCDebug(KRDC) << "Sync key state: " << flags;
+    return freerdp_input_send_synchronize_event(input, flags);
+}
+
 void RdpSession::setState(RdpSession::State newState)
 {
     if (newState == m_state) {
